@@ -45,23 +45,24 @@ public:
     * Set Default picture with written message @p message if no picture or folder was chosen
     * by the user
     **/
-    QPixmap defaultPicture(const QString &message);
+    QImage defaultPicture(const QString &message);
     /**
     * Set picture from location @p currentUrl
     **/
     void setPicture(const KUrl &currentUrl);
-    QPixmap correctRotation(const QPixmap& tempImage, const QString &path);
     KIO::StoredTransferJob * m_job;
     KUrl url();
     QString message();
     void setMessage(const QString &message);
 
 Q_SIGNALS:
-    void pictureLoaded(QPixmap image);
+    void pictureLoaded(QImage image);
 
 private Q_SLOTS:
     void slotFinished(KJob *job);
     void reload();
+    void checkImageLoaded(QImage newImage);
+    void customizeEmptyMessage();
 
 private:
     void setPath(const QString &path);
@@ -70,6 +71,7 @@ private:
     KDirWatch *m_fileWatch;
     QString m_message;
     QString m_defaultImage;
+    bool m_checkDir;
 };
 
 
