@@ -447,6 +447,12 @@ void IncomingMsg::createConfigurationInterface(KConfigDialog *dialog)
     connect(dialog, SIGNAL(okClicked()), this, SLOT(configAccepted()));
 
     dialog->addPage(widget, i18n("General"), icon());
+    
+    connect(ui.showKMail, SIGNAL(toggled(bool)), dialog, SLOT(settingsModified()));
+    connect(ui.showKopete, SIGNAL(toggled(bool)), dialog, SLOT(settingsModified()));
+    connect(ui.showPidgin, SIGNAL(toggled(bool)), dialog, SLOT(settingsModified()));
+    connect(ui.showQutIM, SIGNAL(toggled(bool)), dialog, SLOT(settingsModified()));
+    connect(ui.showXChat, SIGNAL(toggled(bool)), dialog, SLOT(settingsModified()));
 }
 
 
@@ -471,16 +477,20 @@ void IncomingMsg::configAccepted()
 
 void IncomingMsg::slotNewEvolutionMail()
 {
-    KIcon icon("evolution");
-    mEvolutionIconLabel->nativeWidget()->setPixmap(icon.pixmap(32, 32));
-    mEvolutionLabel->setText(i18n("Your Evolution mail count has changed."));
+    if (mEvolutionIconLabel) {
+        KIcon icon("evolution");
+        mEvolutionIconLabel->nativeWidget()->setPixmap(icon.pixmap(32, 32));
+        mEvolutionLabel->setText(i18n("Your Evolution mail count has changed."));
+    }
 }
 
 void IncomingMsg::slotNewKMailMail()
 {
-    KIcon icon("kmail");
-    mKMailIconLabel->nativeWidget()->setPixmap(icon.pixmap(32, 32));
-    mKMailLabel->setText(i18n("Your KMail mail count has changed."));
+    if (mKMailIconLabel) {
+        KIcon icon("kmail");
+        mKMailIconLabel->nativeWidget()->setPixmap(icon.pixmap(32, 32));
+        mKMailLabel->setText(i18n("Your KMail mail count has changed."));
+    }
 }
 
 void IncomingMsg::slotNewXChatIM()
