@@ -345,7 +345,7 @@ void MicroBlog::configChanged()
         getWallet();
     } else { //use config value
         //kDebug() << "password was in config file, using that to get twitter history";
-        downloadHistory();
+        reloadRequired = true;
     }
 
     if (changed) {
@@ -386,11 +386,33 @@ void MicroBlog::reply(const QString &replyToId, const QString &to)
     m_statusEdit->setFocus();
 }
 
-void MicroBlog::forward(const QString &rt)
+void MicroBlog::forward(const QString &messageId)
 {
-    m_scrollWidget->ensureItemVisible(m_headerFrame);
-    m_statusEdit->nativeWidget()->setPlainText(rt);
-    m_statusEdit->setFocus();
+    KConfigGroup cg = m_service->operationDescription("statuses/retweet");
+    cg.writeEntry("id", messageId);
+
+    connect(m_service, SIGNAL(finished(Plasma::ServiceJob*)), this, SLOT(retweetCompleted(Plasma::ServiceJob*)), Qt::UniqueConnection);
+
+    m_retweetJobs.insert(m_service->startOperationCall(cg));
+    setBusy(true);
+}
+
+void MicroBlog::favorite(const QString &messageId, const bool isFavorite)
+{
+    QString operation;
+    if (isFavorite) {
+        operation = "favorites/create";
+    } else {
+        operation = "favorites/destroy";
+    }
+
+    KConfigGroup cg = m_service->operationDescription(operation);
+    cg.writeEntry("id", messageId);
+
+    connect(m_service, SIGNAL(finished(Plasma::ServiceJob*)), this, SLOT(favoriteCompleted(Plasma::ServiceJob*)), Qt::UniqueConnection);
+
+    m_favoriteJobs.insert(m_service->startOperationCall(cg));
+    setBusy(true);
 }
 
 void MicroBlog::getWallet()
@@ -537,14 +559,15 @@ void MicroBlog::dataUpdated(const QString& source, const Plasma::DataEngine::Dat
             //kDebug() << i << m_lastTweet;
             if (i > m_lastTweet) {
                 newCount++;
-                QVariant v = data.value(id);
-                //Warning: This function is not available with MSVC 6
-                Plasma::DataEngine::Data t = v.value<Plasma::DataEngine::Data>();
-                m_tweetMap[i] = t;
+            }
 
-                if (i > maxId) {
-                    maxId = i;
-                }
+            QVariant v = data.value(id);
+            //Warning: This function is not available with MSVC 6
+            Plasma::DataEngine::Data t = v.value<Plasma::DataEngine::Data>();
+            m_tweetMap[i] = t;
+
+            if (i > maxId) {
+                maxId = i;
             }
         }
         //kDebug() << m_lastTweet << maxId << "<-- updated";
@@ -637,6 +660,7 @@ void MicroBlog::showTweets()
         PostWidget *postWidget = new PostWidget(m_tweetsWidget);
         connect(postWidget, SIGNAL(reply(const QString &, const QString &)), this, SLOT(reply(const QString &, const QString &)));
         connect(postWidget, SIGNAL(forward(const QString &)), this, SLOT(forward(const QString &)));
+        connect(postWidget, SIGNAL(favorite(const QString &, const bool)), this, SLOT(favorite(const QString &, const bool)));
         connect(postWidget, SIGNAL(openProfile(const QString &)), this, SLOT(openProfile(const QString &)));
         m_tweetWidgets.append(postWidget);
     }
@@ -699,6 +723,12 @@ void MicroBlog::createConfigurationInterface(KConfigDialog *parent)
     configUi.checkIncludeFriends->setChecked(m_includeFriends);
 
     parent->addPage(configWidget, i18n("General"), icon());
+    connect(configUi.serviceUrlCombo, SIGNAL(editTextChanged(QString)), parent, SLOT(settingsModified()));
+    connect(configUi.usernameEdit, SIGNAL(userTextChanged(QString)), parent, SLOT(settingsModified()));
+    connect(configUi.passwordEdit, SIGNAL(userTextChanged(QString)), parent, SLOT(settingsModified()));
+    connect(configUi.historySizeSpinBox, SIGNAL(valueChanged(int)), parent, SLOT(settingsModified()));
+    connect(configUi.historyRefreshSpinBox, SIGNAL(valueChanged(int)), parent, SLOT(settingsModified()));
+    connect(configUi.checkIncludeFriends, SIGNAL(toggled(bool)), parent, SLOT(settingsModified()));
 }
 
 void MicroBlog::configAccepted()
@@ -776,15 +806,15 @@ bool MicroBlog::eventFilter(QObject *obj, QEvent *event)
 
 void MicroBlog::updateStatus()
 {
+    createTimelineService();
+
     if (!m_service) {
         return;
     }
 
-    createTimelineService();
     QString status = m_statusEdit->nativeWidget()->toPlainText();
 
     KConfigGroup cg = m_service->operationDescription("update");
-    cg.writeEntry("password", m_password);
     cg.writeEntry("status", status);
     if (!m_replyToId.isEmpty()) {
         cg.writeEntry("in_reply_to_status_id", m_replyToId);
@@ -794,6 +824,7 @@ void MicroBlog::updateStatus()
 
     m_updateJobs.insert(m_service->startOperationCall(cg));
     m_statusEdit->nativeWidget()->setPlainText("");
+    setBusy(true);
 }
 
 void MicroBlog::updateCompleted(Plasma::ServiceJob *job)
@@ -813,6 +844,48 @@ void MicroBlog::updateCompleted(Plasma::ServiceJob *job)
     }
 
     //m_statusUpdates.remove(job);
+    setBusy(false);
+}
+
+void MicroBlog::retweetCompleted(Plasma::ServiceJob *job)
+{
+    if (!m_retweetJobs.contains(job)) {
+        return;
+    }
+
+    m_retweetJobs.remove(job);
+    if (m_retweetJobs.isEmpty()) {
+        disconnect(m_service, SIGNAL(finished(Plasma::ServiceJob*)), this, SLOT(retweetCompleted(Plasma::ServiceJob*)));
+    }
+
+    if (!job->error()) {
+        //m_statusUpdates.value(job);
+        downloadHistory();
+        m_flash->flash(i18nc("Repeat of the post also called retweet", "Repeat completed"));
+    } else {
+        m_flash->flash(i18n("Repeat failed"));
+    }
+
+    setBusy(false);
+}
+
+void MicroBlog::favoriteCompleted(Plasma::ServiceJob *job)
+{
+    if (!m_favoriteJobs.contains(job)) {
+        return;
+    }
+
+    m_favoriteJobs.remove(job);
+    if (m_favoriteJobs.isEmpty()) {
+        disconnect(m_service, SIGNAL(finished(Plasma::ServiceJob*)), this, SLOT(favoriteCompleted(Plasma::ServiceJob*)));
+    }
+
+    if (!job->error()) {
+        //m_statusUpdates.value(job);
+        downloadHistory();
+    }
+
+    setBusy(false);
 }
 
 //what this really means now is 'reconnect to the timeline source'
@@ -820,7 +893,7 @@ void MicroBlog::downloadHistory()
 {
    // kDebug() << "Inside downloadhistory";
     if (m_username.isEmpty() || m_password.isEmpty()) {
-		//kDebug() << "BOOHYA got empty password";
+        //kDebug() << "BOOHYA got empty password";
         if (!m_curTimeline.isEmpty()) {
             m_engine->disconnectSource(m_curTimeline, this);
             m_engine->disconnectSource("Error:" + m_curTimeline, this);
@@ -830,17 +903,11 @@ void MicroBlog::downloadHistory()
 
     m_flash->flash(i18n("Refreshing timeline..."), -1);
 
-    if (m_service && m_tabBar->currentIndex() == m_lastMode) {
-        KConfigGroup cg = m_service->operationDescription("refresh");
+    createTimelineService();
+    if (m_service) {
+        KConfigGroup cg = m_service->operationDescription("auth");
+        cg.writeEntry("password", m_password);
         m_service->startOperationCall(cg);
-    } else {
-        createTimelineService();
-
-        if (m_service) {
-            KConfigGroup cg = m_service->operationDescription("auth");
-            cg.writeEntry("password", m_password);
-            m_service->startOperationCall(cg);
-        }
     }
 
     //get the profile to retrieve the user icon
@@ -862,15 +929,16 @@ void MicroBlog::downloadHistory()
 
 void MicroBlog::createTimelineService()
 {
-    if (m_service && m_lastMode == m_tabBar->currentIndex()) {
+    if (!m_tabBar || (m_service && m_lastMode == m_tabBar->currentIndex())) {
         return;
-    } else if (m_service) {
-        delete m_service;
-        m_lastMode = m_tabBar->currentIndex();
     }
 
+    delete m_service;
+    m_service = 0;
+    m_lastMode = m_tabBar->currentIndex();
+
     QString query;
-    switch(m_tabBar->currentIndex()) {
+    switch (m_tabBar->currentIndex()) {
     case 2:
         query = "Messages:%1@%2";
         break;
@@ -878,7 +946,7 @@ void MicroBlog::createTimelineService()
         query = "Replies:%1@%2";
         break;
     default:
-        if(m_includeFriends) {
+        if (m_includeFriends) {
             query = QString("TimelineWithFriends:%1@%2");
         } else {
             query = QString("Timeline:%1@%2");
