@@ -69,7 +69,8 @@ void PanelIcon::configChanged()
     } else { // fallback to default layout
         m_layout = KStandardDirs::locate("data", "plasmaboard/full.xml");
     }
-    if (m_plasmaboard && old_layout != m_layout) { // just rebuild the keyboard if the layout has actually changed
+
+    if (m_plasmaboard && old_layout != m_layout) { // only rebuild the keyboard if the layout has actually changed
         initKeyboard(m_layout);
     }
 }
@@ -103,6 +104,7 @@ void PanelIcon::createConfigurationInterface(KConfigDialog *parent)
     parent->addPage(widget, i18nc("Different keyboard layouts","Layouts"), "plasmaboard");
     connect(parent, SIGNAL(applyClicked()), this, SLOT(configAccepted()));
     connect(parent, SIGNAL(okClicked()), this, SLOT(configAccepted()));
+    
 
     Q_FOREACH(Layout* l, m_layouts){
         ui.layoutsComboBox->addItem(l->name(), l->path());
@@ -113,6 +115,7 @@ void PanelIcon::createConfigurationInterface(KConfigDialog *parent)
     }
 
     connect(ui.layoutsComboBox, SIGNAL(currentIndexChanged(QString)), this, SLOT(layoutNameChanged(QString)));
+    connect(ui.layoutsComboBox, SIGNAL(currentIndexChanged(int)), parent, SLOT(settingsModified()));
 }
 
 QGraphicsWidget *PanelIcon::graphicsWidget()
