@@ -49,24 +49,17 @@
 
 #include "Helpers.h"
 
-#define REPEAT_TIMER 1500
+#define REPEAT_TIMER 1000
 #define STICKY_TIMER 500
 
-QChar Helpers::mapXtoUTF8[0xffff+1];
-int Helpers::keysymsPerKeycode;
-
 PlasmaboardWidget::PlasmaboardWidget(Plasma::PopupApplet *parent)
     : QGraphicsWidget(parent),
       m_applet(parent)
 {
-    setPreferredSize(500, 200);
-    setMinimumSize(200,100);
-    setMaximumSize(20000,10000);
     setWindowFlags(Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint | Qt::X11BypassWindowManagerHint);
     setFocusPolicy(Qt::NoFocus);
     setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
 
-    Helpers::buildUp();
     m_isLevel2 = false;
     m_isAlternative = false;
     m_isLocked = false;
@@ -203,11 +196,11 @@ FuncKey* PlasmaboardWidget::createFunctionKey(const QPoint &point, const QSize &
     else if(action == "KEYPADADD")
         return new FuncKey(point, size, Helpers::keysymToKeycode(XK_KP_Add), QString(i18nc("Plus sign Divider on the keypad", "+")));
     else if(action == "KEYPADSUBTRACT")
-        return new FuncKey(point, size, Helpers::keysymToKeycode(XK_KP_Subtract), QString(i18nc("Plus sign Divider on the keypad", "+")));
+        return new FuncKey(point, size, Helpers::keysymToKeycode(XK_KP_Subtract), QString(i18nc("Minus sign on the keypad", "-")));
     else if(action == "KEYPADENTER")
         return new FuncKey(point, size, Helpers::keysymToKeycode(XK_KP_Enter), QString(i18nc("Enter key on the keypad", "Enter")));
     else if(action == "KEYPADSEPARATOR")
-        return new FuncKey(point, size, Helpers::keysymToKeycode(XK_KP_Separator), QString(i18nc("Seperator key on the keypad", ".")));
+        return new FuncKey(point, size, Helpers::keysymToKeycode(XK_KP_Separator), QString(i18nc("Separator key on the keypad", ".")));
     else if(action == "KEYPAD1")
         return new FuncKey(point, size, Helpers::keysymToKeycode(XK_KP_1), QString(i18nc("1 key on the keypad", "1")));
     else if(action == "KEYPAD2")
@@ -229,7 +222,7 @@ FuncKey* PlasmaboardWidget::createFunctionKey(const QPoint &point, const QSize &
     else if(action == "KEYPAD0")
         return new FuncKey(point, size, Helpers::keysymToKeycode(XK_KP_0), QString(i18nc("0 key on the keypad", "0")));    
     else
-        return new FuncKey(point, size, Helpers::keysymToKeycode(XK_space), QString("Unkown"));
+        return new FuncKey(point, size, Helpers::keysymToKeycode(XK_space), QString(i18n("Unknown")));
 }
 
 FuncKey* PlasmaboardWidget::createStickyKey(const QPoint &point, const QSize &size, const QString &action)
@@ -461,9 +454,10 @@ void PlasmaboardWidget::initKeyboard(const QString &file)
 
             currentPoint = QPoint(0, currentPoint.y() + rowHeight + spacing);
         }
-
     }
 
+    m_keyboardSize = currentSize;
+
     Q_FOREACH(BoardKey* key, m_alphaKeys){
         m_keys << key;
     }
@@ -684,6 +678,28 @@ void PlasmaboardWidget::setTooltip(BoardKey* key)
     }
 }
 
+QSizeF PlasmaboardWidget::sizeHint(Qt::SizeHint which, const QSizeF& constraint) const
+{
+    if(which == Qt::MinimumSize) {
+        return QSizeF(300, 100);
+    }
+    else if(which == Qt::PreferredSize) {
+        if (!m_keyboardSize.isEmpty()) {
+            return m_keyboardSize;
+        } else {
+            return QSizeF(800, 230);
+        }
+    }
+    else if(which == Qt::MaximumSize) {
+        return constraint;
+    }
+    else {
+        return QGraphicsWidget::sizeHint(which, constraint);
+    }
+
+}
+
+
 void PlasmaboardWidget::stickyKey_Mapper(int id)
 {
     BoardKey* key = m_stickyKeys[id];
